| Title: | Item Response Theory Analysis with a 'shiny' Application |
|---|---|
| Description: | Performing Item Response Theory analysis such as parameter estimation, ability estimation, item and model fit analyse, local independence assumption, dimensionality assumption, characteristic and information curves under various models with a user friendly 'shiny' interface. |
| Authors: | Huseyin Yildiz [aut, cre] |
| Maintainer: | Huseyin Yildiz <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1 |
| Built: | 2026-06-07 09:20:47 UTC |
| Source: | https://github.com/cran/shinyIRT |
Performing Item Response Thory analysis such as paramater estimation, ability estimation, item and model fit analyse, local independence assumption, dimensionality assumption, charachteristic and information curves under various models with a user friendly 'shiny' interface.
shinyIRT()shinyIRT()
No return value, launches 'shiny' application
if(interactive()){ ## Run this code for launching the 'shiny' application shinyIRT() }if(interactive()){ ## Run this code for launching the 'shiny' application shinyIRT() }