Welcome to ClientVPS Mirrors

Help for package shinyIRT
Type: Package
Title: Item Response Theory Analysis with a 'shiny' Application
Version: 0.1
Author: Huseyin Yildiz [aut, cre]
Maintainer: Huseyin Yildiz <huseyinyildiz35@gmail.com>
Description: Performing Item Response Theory analysis such as parameter estimation, ability estimation, item and model fit analyse, local independence assumption, dimensionality assumption, characteristic and information curves under various models with a user friendly 'shiny' interface.
Imports: magrittr, shiny, shinydashboard, shinycssloaders, readxl, stats, mirt, psych, irtoys
License: GPL (≥ 3)
Encoding: UTF-8
LazyData: true
NeedsCompilation: no
Packaged: 2021-01-10 14:16:03 UTC; husey
Repository: CRAN
Date/Publication: 2021-01-13 18:30:02 UTC

Item Response Theory Analysis with a Shiny Application

Description

Performing Item Response Thory analysis such as paramater estimation, ability estimation, item and model fit analyse, local independence assumption, dimensionality assumption, charachteristic and information curves under various models with a user friendly 'shiny' interface.

Usage

shinyIRT()

Value

No return value, launches 'shiny' application

Examples

if(interactive()){
## Run this code for launching the 'shiny' application
shinyIRT()
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.